Struct Haar
pub struct Haar { /* private fields */ }Expand description
The Haar wavelet - the simplest orthogonal wavelet
The Haar wavelet is a square wave with one positive and one negative value. It’s the simplest wavelet and is useful for educational purposes and applications requiring fast computation.
Implementations